==> preloadify-1.0.3.tgz: package/README.md <==
# Preloadify 🌌
A __dead__ simple  image preloader for the web.  <br/>
Zero dependecies, super lightweight.  <br/>
Requires ES6 promises to work.

## Installation 💿
Preloadify can be installed in ES Modules syntax:
```js
import preloadify from "preloadify"
```
as a script tag:
```html
<script src="https://cdn.jsdelivr.net/npm/preloadify@latest/dist/index.min.js"></script>
<script>
    preloadify = preloadify.default; // Initalize
</script>
```
as a commonjs module:
```js
const {preloadify} = require("preloadify");
``` 
and as a AMD require:
```js
require(['preloadify'], function ({preloadify}) {
  preloadify(...);
});
```

## API 🐱‍👤

As said earlier, this package is __dead__ simple.
```js
async function dummyFunc() {
    await preloadify([src1, src2]);
    // OR
    await preloadify('src1');
    // Images are preloaded 🎉
    // <img src="src1"> will instantly load the image
}
function dummyFunc() {
    preloadify([src1, src2]).then(() => {
        // Images are preloaded 🎉
    })
}
```
As easy as that.  <br/>
There is a also on optional 'options' argument.  <br/>
It can have two properties:  <br/>
__oneach__:
```js
preloadify([src1, src2], {
    oneach(src) {
        // Called when a single image fully loads
        // and passes in that image's src
        console.log(`Image with source ${src} was loaded`);
    }
});
```
__onprogress__:
```js
preloadify([src1, src2], {
    onprogress(percents, [done, total]) {
        // Called the same time as oneach
        // Provides info on loading progress
        console.log(`Loading: ${percents}%`);
        // OR
        console.log(`Loading: ${done} of ${total}}`);
    }
});
```
Easy, right? 😀

==> preloadify-1.0.4.tgz: package/README.md <==
# Preloadify 🌌
A __dead__ simple  image preloader for the web.  <br/>
Zero dependecies, super lightweight.  <br/>
Requires ES6 promises to work.

## Installation 💿
Preloadify can be installed in ES Modules syntax:
```js
import preloadify from "preloadify"
```
as a script tag:
```html
<script src="https://cdn.jsdelivr.net/npm/preloadify@latest/dist/index.min.js"></script>
<script>
    preloadify = preloadify.default; // Initalize
</script>
```
as a commonjs module:
```js
const {preloadify} = require("preloadify");
``` 
and as a AMD require:
```js
require(['preloadify'], function ({preloadify}) {
  preloadify(...);
});
```

## API 🐱‍👤

As said earlier, this package is __dead__ simple.
```js
async function dummyFunc() {
    await preloadify([src1, src2]);
    // OR
    await preloadify('src1');
    // Images are preloaded 🎉
    // <img src="src1"> will instantly load the image
}
function dummyFunc() {
    preloadify([src1, src2]).then(() => {
        // Images are preloaded 🎉
    })
}
```
As easy as that.  <br/>
There is a also an optional 'options' argument.  <br/>
It can have two properties:  <br/>
__oneach__:
```js
preloadify([src1, src2], {
    oneach(src) {
        // Called when a single image fully loads
        // and passes in that image's src
        console.log(`Image with source ${src} was loaded`);
    }
});
```
__onprogress__:
```js
preloadify([src1, src2], {
    onprogress(percents, [done, total]) {
        // Called the same time as oneach
        // Provides info on loading progress
        console.log(`Loading: ${percents}%`);
        // OR
        console.log(`Loading: ${done} of ${total}}`);
    }
});
```
Easy, right? 😀
